Molecular Interaction Analyzer
==============================

.. automodule:: hbat.core.np_analyzer
   :members:
   :undoc-members:
   :show-inheritance:

Interaction Calculation Methods
--------------------------------

The following private methods perform the core interaction calculations:

.. automethod:: hbat.core.np_analyzer.NPMolecularInteractionAnalyzer._find_hydrogen_bonds_vectorized

.. automethod:: hbat.core.np_analyzer.NPMolecularInteractionAnalyzer._find_halogen_bonds_vectorized

.. automethod:: hbat.core.np_analyzer.NPMolecularInteractionAnalyzer._find_pi_interactions_vectorized

.. automethod:: hbat.core.np_analyzer.NPMolecularInteractionAnalyzer._find_pi_pi_interactions_vectorized

.. automethod:: hbat.core.np_analyzer.NPMolecularInteractionAnalyzer._find_carbonyl_interactions_vectorized

.. automethod:: hbat.core.np_analyzer.NPMolecularInteractionAnalyzer._find_n_pi_interactions_vectorized

.. automethod:: hbat.core.np_analyzer.NPMolecularInteractionAnalyzer._find_cooperativity_chains

